@@ -83,7 +83,7 @@ searchInput <- function(inputId, label = NULL, value = "", placeholder = NULL,
       id = inputId, `data-reset` = !is.null(resetValue),
       `data-reset-value` = resetValue,
       class = "input-group search-text",
-      htmltools::tags$input(id = paste0("se", inputId),
+      htmltools::tags$input(id = paste0(inputId, "_text"),
                  style = "border-radius: 0.25em 0 0 0.25em !important;",
                  type = "text", class = "form-control", value = value,
                  placeholder = placeholder),
